from fastapi import APIRouter, Depends
from fastapi_pagination import paginate, Params
from pydantic import BaseModel
from sqlalchemy.orm import Session

from app import schemas, get_db, crud
from app.core.k8s.k8s_client import KubernetesTools
from app.schemas import AirflowRunCreate
from utils import web_try, sxtimeit


class Item(BaseModel):
    data: dict


router_af_run = APIRouter(
    prefix="/jpt/af_run",
    tags=["airflow_run-运行管理"],
)


@router_af_run.get("/")
@web_try()
@sxtimeit
def get_tasks(params: Params = Depends(), db: Session = Depends(get_db)):
    return paginate(crud.get_airflow_tasks(db), params)


@router_af_run.post("/")
@web_try()
@sxtimeit
def add_job(item: schemas.AirflowJobCreate, db: Session = Depends(get_db)):
    return crud.create_airflow_job(db, item)


@router_af_run.post("/notification")
@web_try()
@sxtimeit
def add_notification(item: Item, db: Session = Depends(get_db)):
    print(f'input : {item.data} ')
    k8s_tool = KubernetesTools()
    labels = {"dag_id": item.data['dag_id'],
              "task_id": item.data['task_id'],
              "run_ts": item.data['run_ts']}
    logs = k8s_tool.get_pod_logs(namespaces="airflow", labels=labels)

    run_id = item.data['run_id']

    # run_item = crud.get_airflow_run_once(db=db,run_id=run_id)
    # return
    # if run_item is not None:
    #     pass
    # else:
    #     item:AirflowRunCreate = AirflowRunCreate({"start_time":})
    #     # crud.create_airflow_run(db=db,r)
    #     # create
    #     pass

    print(f'logs are {logs}')
    return
